from setuptools import setup, find_packages

setup(
name='LoggingToolkit',
version=0.1,
license='MIT',
author='Surendra Babu Bapatla',
author_email='ben10.surendra@gmail.com',
package_dir={'':'src'},
url=r'',
keywords='example project',
install_requires=[''],
packages=find_packages('src'),
)
